@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
 
+from collections import defaultdict
+
+
 class AuthorizationError(Exception):
     """
     The client encountered an HTTP 403 error and is passing it on
@@ -15,32 +18,46 @@ class AuthorizationError(Exception):
             (self.url, self.reason)
 
 
-class PropsetError(Exception):
-    pass
-
-class PropfindError(Exception):
-    pass
-
-class ReportError(Exception):
-    pass
-
-class MkcolError(Exception):
-    pass
-
-class MkcalendarError(Exception):
-    pass
-
-class PutError(Exception):
+class DAVError(Exception):
     pass
 
 
-class DeleteError(Exception):
+class PropsetError(DAVError):
     pass
 
-class NotFoundError(Exception):
+class ProppatchError(DAVError):
     pass
 
-exception_by_method = {}
-for method in ('delete', 'put', 'mkcalendar', 'mkcol', 'report', 'propset', 'propfind'):
-    exception_by_method[method] = locals()[method[0].upper() + method[1:] + 'Error']
-    
+
+class PropfindError(DAVError):
+    pass
+
+
+class ReportError(DAVError):
+    pass
+
+
+class MkcolError(DAVError):
+    pass
+
+
+class MkcalendarError(DAVError):
+    pass
+
+
+class PutError(DAVError):
+    pass
+
+
+class DeleteError(DAVError):
+    pass
+
+
+class NotFoundError(DAVError):
+    pass
+
+exception_by_method = defaultdict(lambda: DAVError)
+for method in ('delete', 'put', 'mkcalendar', 'mkcol', 'report', 'propset',
+               'propfind', 'proppatch'):
+    exception_by_method[method] = \
+        locals()[method[0].upper() + method[1:] + 'Error']
